// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Annotations;
using System.Collections.Generic;
using GrapeCity.Documents.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、PDF ドキュメント内の2つの単語をすべて検索し、検索結果すべてを
    // テキストマークアップ注釈の下線を使用して強調表示する方法を紹介しています。
    public class FindAndUnderline
    {
        public int CreatePDF(Stream stream)
        {
            // PDF を読み込みます。
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "diodocs_flyer.pdf"));
            doc.Load(fs);

            // 正規表現を使用して、「Standard」と「API」をすべて検索します。
            var ft = new FindTextParams("Standard|API", wholeWord: false, matchCase: false, regex: true);
            var found = doc.FindText(ft, null);

            // テキストマークアップ注釈を追加し、検索結果すべてに下線を引きます。
            foreach (var f in found)
            {
                var markup = new TextMarkupAnnotation()
                {
                    Page = doc.Pages[f.PageIndex],
                    MarkupType = TextMarkupType.Underline,
                    Color = Color.Red
                };
                List<Quadrilateral> area = new List<Quadrilateral>();
                foreach (var b in f.Bounds)
                    area.Add(b);
                markup.Area = area;
            }

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
